# Why Ibis Birdbrain?

[Ibis](https://ibis-project.org) is the portable Python dataframe library.

Ibis Birdbrain is the portable Python LM-powered data bot, built on Ibis with
support for all data platforms Ibis's 20+ backends support. Ibis Birdbrain is
also built on [Marvin](https://github.com/PrefectHQ/marvin) with support for all
AI platforms Marvin supports.

## Language models (LMs)

Langauge models have...

## Standards

> > When things don't work as they should, it often means that standards are absent.
> >
> > \- [The International Organization for Standardization (ISO)](https://www.iso.org/standards.html)
> 
> \- [The Composable Codex](https://voltrondata.com/codex/standards-over-silos)

## Composable data systems are MICE

[Composable data systems are MICE: modular, interoperable, customizable, and extensible](https://voltrondata.com/codex/standards-over-silos).

Ibis Birdbrain aims to bring these values to a data + AI framework that makes working with LLMs delightful and easy, for individual hobbiests or the more advanced technology organizations.

